<?php

namespace Supportingcast;

class Api {

	private $baseUrl = '';
	private $token = '';
	private $response;
	private $body;

	public function __construct() {
		$this->baseUrl = 'https://api' . SC_API_DOMAIN_BASE . '/v1/';
		$this->token = get_option('sc-token');
	}

	public function post(string $path, ?array $body = null): void
	{
		$this->call('post', $path, $body);
	}

	public function get(string $path, ?array $body = null): void
	{
		$this->call('get', $path, $body);
	}

	public function call(string $method, string $path, ?array $body = null): void
	{

		$path = $this->baseUrl . $path;
		$params = $this->getBaseParams();
		if ($body) {
			$params['body'] = json_encode($body);
		}
		$f = "wp_remote_{$method}";
		$this->response = $f($path, $params);
	}

	public function success(): bool
	{
		return !is_wp_error($this->response) && $this->response['response']['code'] < 400;
	}

	public function getErrorMsg(): string
	{
		if (is_wp_error($this->response)) {
			return $this->response->get_error_message();
		}
		return '<i>' . $this->response['response']['code'] . ' '
		       . $this->response['response']['message'] . '</i> error from server. Please try again.';
	}

	public function getResponse()
	{
		$this->getResponse();
	}

	public function getBody()
	{
		if (!$this->body) {
			$this->body = json_decode($this->response['body']);
		}
		return $this->body;
	}

	private function getBaseParams()
	{
		return [
			'headers' => [
				'Authorization' => 'Bearer ' . $this->token,
				'Content-type' => 'application/json',
				'Accept' => 'application/json',
			],
			'sslverify' => false,
		];
	}
}